===============
Recent Listings
===============


Working With Recent Listings
============================

Activate Recent Listings
------------------------

To show recent listings within your site, go to the place in your Plone site where you want to have the recent listings collection available and open the **Actions**-menu.
Select **Activate Recent Listings** from the available options:

.. figure:: ../../_images/recent_listings_activate.png

   Activate a recent listings collection

When the **Recent Listings** collection was activated, you will see a status message:

.. figure:: ../../_images/recent_listings_activate_done.png

   Confirmation that the recent listings collection has been activated

This will by default show you all available listings from your connected MLS.

.. figure:: ../../_images/recent_listings_default.png

   List of listings after recent listings collection has been activated


Deactivate Recent Listings
--------------------------

You can disable the embedding of a recent listings collection at any time.
When you deactivate the embedding, your configuration will not be removed.
So if you later decide to enable the embedding again, you don't have to start from the beginning.

To de-activate the **Recent Listings** collection again, open the **Actions**-menu and select **Deactivate Recent Listings**:

.. figure:: ../../_images/recent_listings_deactivate.png

   Deactivate a recent listings collection

When the **Recent Listings** collection was deactivated, you will see a status message:

.. figure:: ../../_images/recent_listings_deactivate_done.png

   Confirmation that the recent listings collection has been deactivated


Configuration Options
=====================

To configure the **Recent Listings** collection click on the new link **Configure Recent Listings**:

.. figure:: ../../_images/recent_listings_configuration.png

   Configuration options for a recent listings collection

Once all configuration options are entered click the **Save** button.
